<?php
// This file is part of Moodle - https://moodle.org/
//
// Moodle is free software: you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation, either version 3 of the License, or
// (at your option) any later version.
//
// Moodle is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with Moodle.  If not, see <https://www.gnu.org/licenses/>.

/**
 * Main plugin file
 * @package     local_aatplugin
 * @copyright   2023 Joseph Larochelle <larochellejo@hotmail.com>
 * @license     https://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
 */
use local_aatplugin\form\dump_form;
require_once('../../config.php');
require_once("$CFG->libdir/formslib.php");
require_once($CFG->dirroot . '/local/aatplugin/lib.php');
require_once($CFG->dirroot . '/local/aatplugin/classes/form/dump_form.php');
require_once($CFG->dirroot . '/local/aatplugin/classes/data_dump.php');

// Set up the page context and properties.
global $PAGE, $SITE;
$context = context_system::instance();
$PAGE->set_context($context);
$PAGE->set_url(new moodle_url('/local/aatplugin/index.php'));
$PAGE->set_pagelayout('standard');
$PAGE->set_title($SITE->fullname);
$PAGE->set_heading(get_string('pluginname', 'local_aatplugin'));
require_login();

// Output the header and plugin information.
echo $OUTPUT->header();
echo get_string('infomessage', 'local_aatplugin');
echo '<hr>'; // Visual separation.

// Fetch user's courses and prepare form.
$courses = local_aatplugin_fetch_user_courses();
$dumpform = new dump_form(null, ['courses' => $courses]);
local_aatplugin_process_form_submission($dumpform);

// Always display the link to AAT website at the bottom.
echo '<hr>';
local_aatplugin_display_instructions();
echo $OUTPUT->footer();











